@@ -1,24 +1,19 @@
-from typing import List
+from .resource_manager import assets_root
 from httpx import AsyncClient
-from os import path, listdir, makedirs
 from tqdm import tqdm
+from os import listdir, makedirs
+from typing import List
 from .config import config
-from ._RHelper import RHelper
 
-root = RHelper()
+src_api_url = config.get_config("src_url")
 
 
 async def check_song_update() -> List[str]:
-    async with AsyncClient() as client:
-
-        src_api_url = config.get_config("src_url")
-        song_dir = root.assets.song
-
-        if not path.exists(song_dir):
-            makedirs(song_dir, exist_ok=True)
-
+    song_dir = assets_root / "song"
+    song_dir.mkdir(exist_ok=True, parents=True)
+    async with AsyncClient(timeout=100) as client:
         resp1 = await client.get(src_api_url + "song_list")
-        result = list()
+        result = []
         for k, v in tqdm((resp1.json()).items()):
             if k not in listdir(song_dir):
                 for link in v:
@@ -32,14 +27,9 @@ async def check_song_update() -> List[str]:
 
 
 async def check_char_update() -> List[str]:
-    async with AsyncClient() as client:
-
-        src_api_url = config.get_config("src_url")
-        char_dir = root.assets.char
-
-        if not path.exists(char_dir):
-            makedirs(char_dir, exist_ok=True)
-
+    char_dir = assets_root / "char"
+    char_dir.mkdir(exist_ok=True, parents=True)
+    async with AsyncClient(timeout=100) as client:
         resp1 = await client.get(src_api_url + "char_list")
         result = list()
         for k, v in tqdm((resp1.json()).items()):
